from uploader_client.interfaces.base import (
    AbstractInterface,
    AbstractRequest,
    AbstractResult,
)
from uploader_client.interfaces.rest import (
    OpenAPIInterface,
    OpenAPIRequest,
    Result,
)


__all__ = [
    'AbstractInterface',
    'AbstractRequest',
    'AbstractResult',
    'OpenAPIRequest',
    'OpenAPIInterface',
    'Result',
]
